==> mutter-2.91.5.tar.bz2: mutter-2.91.5/src/mutter-enum-types.h <==

/* Generated data (by glib-mkenums) */

#ifndef __MUTTER_ENUM_TYPES_H__
#define __MUTTER_ENUM_TYPES_H__

#include <glib-object.h>

G_BEGIN_DECLS

/* enumerations from "include/boxes.h" */
GType meta_edge_type_get_type (void) G_GNUC_CONST;
#define MUTTER_TYPE_EDGE_TYPE (meta_edge_type_get_type())

/* enumerations from "ui/gradient.h" */
GType meta_gradient_type_get_type (void) G_GNUC_CONST;
#define MUTTER_TYPE_GRADIENT_TYPE (meta_gradient_type_get_type())

/* enumerations from "include/main.h" */
GType meta_exit_code_get_type (void) G_GNUC_CONST;
#define MUTTER_TYPE_EXIT_CODE (meta_exit_code_get_type())

/* enumerations from "include/util.h" */
GType meta_debug_topic_get_type (void) G_GNUC_CONST;
#define MUTTER_TYPE_DEBUG_TOPIC (meta_debug_topic_get_type())

GType meta_later_type_get_type (void) G_GNUC_CONST;
#define MUTTER_TYPE_LATER_TYPE (meta_later_type_get_type())

/* enumerations from "include/common.h" */
GType meta_frame_flags_get_type (void) G_GNUC_CONST;
#define MUTTER_TYPE_FRAME_FLAGS (meta_frame_flags_get_type())

GType meta_menu_op_get_type (void) G_GNUC_CONST;
#define MUTTER_TYPE_MENU_OP (meta_menu_op_get_type())

GType meta_grab_op_get_type (void) G_GNUC_CONST;
#define MUTTER_TYPE_GRAB_OP (meta_grab_op_get_type())

GType meta_cursor_get_type (void) G_GNUC_CONST;
#define MUTTER_TYPE_CURSOR (meta_cursor_get_type())

GType meta_focus_mode_get_type (void) G_GNUC_CONST;
#define MUTTER_TYPE_FOCUS_MODE (meta_focus_mode_get_type())

GType meta_focus_new_windows_get_type (void) G_GNUC_CONST;
#define MUTTER_TYPE_FOCUS_NEW_WINDOWS (meta_focus_new_windows_get_type())

GType meta_action_titlebar_get_type (void) G_GNUC_CONST;
#define MUTTER_TYPE_ACTION_TITLEBAR (meta_action_titlebar_get_type())

GType meta_frame_type_get_type (void) G_GNUC_CONST;
#define MUTTER_TYPE_FRAME_TYPE (meta_frame_type_get_type())

GType meta_virtual_modifier_get_type (void) G_GNUC_CONST;
#define MUTTER_TYPE_VIRTUAL_MODIFIER (meta_virtual_modifier_get_type())

GType meta_direction_get_type (void) G_GNUC_CONST;
#define MUTTER_TYPE_DIRECTION (meta_direction_get_type())

GType meta_motion_direction_get_type (void) G_GNUC_CONST;
#define MUTTER_TYPE_MOTION_DIRECTION (meta_motion_direction_get_type())

GType meta_side_get_type (void) G_GNUC_CONST;
#define MUTTER_TYPE_SIDE (meta_side_get_type())

GType meta_button_function_get_type (void) G_GNUC_CONST;
#define MUTTER_TYPE_BUTTON_FUNCTION (meta_button_function_get_type())

GType meta_stack_layer_get_type (void) G_GNUC_CONST;
#define MUTTER_TYPE_STACK_LAYER (meta_stack_layer_get_type())

/* enumerations from "include/prefs.h" */
GType meta_preference_get_type (void) G_GNUC_CONST;
#define MUTTER_TYPE_PREFERENCE (meta_preference_get_type())

GType meta_key_binding_action_get_type (void) G_GNUC_CONST;
#define MUTTER_TYPE_KEY_BINDING_ACTION (meta_key_binding_action_get_type())

GType meta_visual_bell_type_get_type (void) G_GNUC_CONST;
#define MUTTER_TYPE_VISUAL_BELL_TYPE (meta_visual_bell_type_get_type())

/* enumerations from "include/window.h" */
GType meta_window_type_get_type (void) G_GNUC_CONST;
#define MUTTER_TYPE_WINDOW_TYPE (meta_window_type_get_type())

GType meta_maximize_flags_get_type (void) G_GNUC_CONST;
#define MUTTER_TYPE_MAXIMIZE_FLAGS (meta_maximize_flags_get_type())

/* enumerations from "include/compositor.h" */
GType meta_comp_effect_get_type (void) G_GNUC_CONST;
#define MUTTER_TYPE_COMP_EFFECT (meta_comp_effect_get_type())

/* enumerations from "include/display.h" */
GType meta_tab_list_get_type (void) G_GNUC_CONST;
#define MUTTER_TYPE_TAB_LIST (meta_tab_list_get_type())

GType meta_tab_show_type_get_type (void) G_GNUC_CONST;
#define MUTTER_TYPE_TAB_SHOW_TYPE (meta_tab_show_type_get_type())

GType meta_atom_get_type (void) G_GNUC_CONST;
#define MUTTER_TYPE_ATOM (meta_atom_get_type())

/* enumerations from "include/meta-plugin.h" */
GType meta_modal_options_get_type (void) G_GNUC_CONST;
#define MUTTER_TYPE_MODAL_OPTIONS (meta_modal_options_get_type())

G_END_DECLS

#endif /* !__MUTTER_ENUM_TYPES_H__ */

/* Generated data ends here */

==> mutter_3.2.1.orig.tar.bz2: mutter-3.2.1/src/mutter-enum-types.h <==

/* Generated data (by glib-mkenums) */

#ifndef __MUTTER_ENUM_TYPES_H__
#define __MUTTER_ENUM_TYPES_H__

#include <glib-object.h>

G_BEGIN_DECLS

/* enumerations from "meta/boxes.h" */
GType meta_edge_type_get_type (void) G_GNUC_CONST;
#define MUTTER_TYPE_EDGE_TYPE (meta_edge_type_get_type())

/* enumerations from "meta/common.h" */
GType meta_frame_flags_get_type (void) G_GNUC_CONST;
#define MUTTER_TYPE_FRAME_FLAGS (meta_frame_flags_get_type())

GType meta_menu_op_get_type (void) G_GNUC_CONST;
#define MUTTER_TYPE_MENU_OP (meta_menu_op_get_type())

GType meta_grab_op_get_type (void) G_GNUC_CONST;
#define MUTTER_TYPE_GRAB_OP (meta_grab_op_get_type())

GType meta_cursor_get_type (void) G_GNUC_CONST;
#define MUTTER_TYPE_CURSOR (meta_cursor_get_type())

GType meta_focus_mode_get_type (void) G_GNUC_CONST;
#define MUTTER_TYPE_FOCUS_MODE (meta_focus_mode_get_type())

GType meta_focus_new_windows_get_type (void) G_GNUC_CONST;
#define MUTTER_TYPE_FOCUS_NEW_WINDOWS (meta_focus_new_windows_get_type())

GType meta_action_titlebar_get_type (void) G_GNUC_CONST;
#define MUTTER_TYPE_ACTION_TITLEBAR (meta_action_titlebar_get_type())

GType meta_frame_type_get_type (void) G_GNUC_CONST;
#define MUTTER_TYPE_FRAME_TYPE (meta_frame_type_get_type())

GType meta_virtual_modifier_get_type (void) G_GNUC_CONST;
#define MUTTER_TYPE_VIRTUAL_MODIFIER (meta_virtual_modifier_get_type())

GType meta_direction_get_type (void) G_GNUC_CONST;
#define MUTTER_TYPE_DIRECTION (meta_direction_get_type())

GType meta_motion_direction_get_type (void) G_GNUC_CONST;
#define MUTTER_TYPE_MOTION_DIRECTION (meta_motion_direction_get_type())

GType meta_side_get_type (void) G_GNUC_CONST;
#define MUTTER_TYPE_SIDE (meta_side_get_type())

GType meta_button_function_get_type (void) G_GNUC_CONST;
#define MUTTER_TYPE_BUTTON_FUNCTION (meta_button_function_get_type())

GType meta_stack_layer_get_type (void) G_GNUC_CONST;
#define MUTTER_TYPE_STACK_LAYER (meta_stack_layer_get_type())

/* enumerations from "meta/compositor.h" */
GType meta_comp_effect_get_type (void) G_GNUC_CONST;
#define MUTTER_TYPE_COMP_EFFECT (meta_comp_effect_get_type())

/* enumerations from "meta/display.h" */
GType meta_tab_list_get_type (void) G_GNUC_CONST;
#define MUTTER_TYPE_TAB_LIST (meta_tab_list_get_type())

GType meta_tab_show_type_get_type (void) G_GNUC_CONST;
#define MUTTER_TYPE_TAB_SHOW_TYPE (meta_tab_show_type_get_type())

GType meta_atom_get_type (void) G_GNUC_CONST;
#define MUTTER_TYPE_ATOM (meta_atom_get_type())

/* enumerations from "meta/gradient.h" */
GType meta_gradient_type_get_type (void) G_GNUC_CONST;
#define MUTTER_TYPE_GRADIENT_TYPE (meta_gradient_type_get_type())

/* enumerations from "meta/main.h" */
GType meta_exit_code_get_type (void) G_GNUC_CONST;
#define MUTTER_TYPE_EXIT_CODE (meta_exit_code_get_type())

/* enumerations from "meta/meta-plugin.h" */
GType meta_modal_options_get_type (void) G_GNUC_CONST;
#define MUTTER_TYPE_MODAL_OPTIONS (meta_modal_options_get_type())

/* enumerations from "meta/prefs.h" */
GType meta_preference_get_type (void) G_GNUC_CONST;
#define MUTTER_TYPE_PREFERENCE (meta_preference_get_type())

GType meta_key_binding_action_get_type (void) G_GNUC_CONST;
#define MUTTER_TYPE_KEY_BINDING_ACTION (meta_key_binding_action_get_type())

GType meta_visual_bell_type_get_type (void) G_GNUC_CONST;
#define MUTTER_TYPE_VISUAL_BELL_TYPE (meta_visual_bell_type_get_type())

/* enumerations from "meta/screen.h" */
GType meta_screen_corner_get_type (void) G_GNUC_CONST;
#define MUTTER_TYPE_SCREEN_CORNER (meta_screen_corner_get_type())

/* enumerations from "meta/util.h" */
GType meta_debug_topic_get_type (void) G_GNUC_CONST;
#define MUTTER_TYPE_DEBUG_TOPIC (meta_debug_topic_get_type())

GType meta_later_type_get_type (void) G_GNUC_CONST;
#define MUTTER_TYPE_LATER_TYPE (meta_later_type_get_type())

/* enumerations from "meta/window.h" */
GType meta_window_type_get_type (void) G_GNUC_CONST;
#define MUTTER_TYPE_WINDOW_TYPE (meta_window_type_get_type())

GType meta_maximize_flags_get_type (void) G_GNUC_CONST;
#define MUTTER_TYPE_MAXIMIZE_FLAGS (meta_maximize_flags_get_type())

G_END_DECLS

#endif /* !__MUTTER_ENUM_TYPES_H__ */

/* Generated data ends here */
